# QtTree
QtTree provides a graphical user interface for editing and visualizing tree data structure.

## Basic usage
Check [demo.py](https://github.com/ktrk115/qt-tree/blob/master/demo.py) to know how this library can use.

## License
MIT License.

## Reference
QtTree exploits the following libraries:
- https://github.com/LeGoffLoic/Nodz
- https://github.com/c0fec0de/anytree
